Possible improvements
=====================

* improve docstrings
* typing annotations
* improve mosaicking algorithm
* improve KMZ generation
* improve documentation and tutorials
* improve documentation theme and styling
